@@ -51,11 +51,11 @@ class SMILEVisitor(NodeVisitor):
         if type(visited_children[0]) is dict:  #  (ComparisonExpression)
             op = visited_children[0]["name"]
             args = visited_children[0]["args"]
-            return {"name": op, "type": 'operator', "args": args}
+            return {"name": op.strip(), "type": 'operator', "args": args}
 
         else: # Exactly 3 Elements expected in tree
             left, op, right = visited_children[0] # (ComparisonExpression BooleanOperator ConditionalStatement)
-            return {"name": op, "type": 'operator', "args": [left, right]}
+            return {"name": op.strip(), "type": 'operator', "args": [left, right]}
 
 
     def visit_ComparisonExpression(self, node, visited_children):
@@ -76,14 +76,14 @@ class SMILEVisitor(NodeVisitor):
             left, op, right = visited_children[0]
             args = [left, right]
 
-            return {"name": op, "type": 'operator', "args": args}
+            return {"name": op.strip(), "type": 'operator', "args": args}
 
         return visited_children[0]
 
     def visit_Term(self, node, visited_children):
         if type(visited_children[0]) == list:
             left, op, right = visited_children[0]
-            return {"name": op.replace(" ","").lower(), "type": 'operator', "args": [left, right]}
+            return {"name": op.strip().lower(), "type": 'operator', "args": [left, right]}
         return visited_children[0]
 
     def visit_Atom(self, node, visited_children):
@@ -281,12 +281,12 @@ The Actual Grammar
 grammar = Grammar(
     r"""
     equation                =  Sentence 
-    Sentence                =  _?  ( Comment / ConditionalExpression / ConditionalStatement / Expression / nothing ) _?
-    Comment                 = _ "{" ~"[A-Z 0-9]*"i "}" _
+    Sentence                =  _  ( Comment / ConditionalExpression / ConditionalStatement / Expression / nothing ) _
+    Comment                 = _ "{" ~"[\w\d\s]*"iu "}" _
     ConditionalExpression   =  (if _ Sentence _ then _ Sentence _ else _ Sentence)  / (if _ Sentence _ then _ Sentence)
     ConditionalStatement    = (ComparisonExpression BooleanOperator ConditionalStatement) / (ComparisonExpression)
     Not                     = ~"NOT"i 
-    ComparisonExpression    = (Expression ComparisonOperator Expression ) / ( Not "(" Expression ComparisonOperator Expression ")" )
+    ComparisonExpression    = (Expression ComparisonOperator Expression ) / ( Not bracket_open Expression ComparisonOperator Expression bracket_closed )
     Expression              = (Term AdditiveOperator Sentence)  / (Term)
     Term                    = (Atom MultiplicativeOperator Term)  / (Atom)
     Atom                    = NumericLiteral
@@ -294,7 +294,7 @@ grammar = Grammar(
                               / SpecialFunction
                               / ArrayExpression
                               / Identifier
-                              / ('(' Sentence ')')
+                              / (bracket_open Sentence bracket_closed)
                               / nothing   
     NumericLiteral          = (significant fraction exponent)
                               / (significant fraction)            
@@ -307,20 +307,23 @@ grammar = Grammar(
     exponent                = ( 'e-' / 'e' ) digits 
     fraction                = '.'digits
 
-    digits                  = ~"[0-9]+"
+    digits                  = ~"[\d]+"
 
     AdditiveOperator        = _ ('+' / '-' ) _  
-    MultiplicativeOperator  = _ ( '*' / '/' / '^' / ~"MOD"i ) _    
+    MultiplicativeOperator  = _ ( Asterisk / '/' / '^' / ~"MOD"i ) _    
     ComparisonOperator      = _ ( '>=' / '=' / '<=' / '<>' / '<' / '>' ) _ 
     BooleanOperator         = _ ( and / or ) _   
 
-    FunctionExpression      = Identifier '(' FunctionArguments ')'                 
+    FunctionExpression      = Identifier bracket_open FunctionArguments bracket_closed                 
     FunctionArguments       = (FunctionArgument ( ArgumentSeparator FunctionArgument )+)   / (Sentence)
     FunctionArgument        =  ( ((ArrayExpression) / (Expression)) ((AdditiveOperator) / (MultiplicativeOperator)) Term)  / ArrayExpression / Sentence                      
     SpecialFunction         = _ ( ~'starttime'i / ~'stoptime'i / ~'time'i / ~'dt'i / ~'pi'i / ~'clocktime'i / ~'nan'i / ~'inf'i ) !Name 
 
     Identifier              =  (EnclosedIdentifier) / (NamespacedIdentifier) / (SimpleIdentifier)
-    EnclosedIdentifier      = '"' ~"[a-zA-Z0-9_%\$€£¥&§\*\-()/]"+ '"'
+    EnclosedIdentifier      = BeginQuote NameWithSpecialChars EndQuote
+    BeginQuote              = Quote
+    EndQuote                = Quote
+    Quote                   = '"'
     SimpleIdentifier        = !Keyword Name
     NamespacedIdentifier    = (!Keyword ( Name '.' Name )) / (!Keyword ( '.' Name ))
 
@@ -339,13 +342,16 @@ grammar = Grammar(
     or                      =  ~"OR"i &Separator
 
 
-    Name                    = ( ~"[\"]?" ~"[a-zA-Z0-9_%\$€£¥&§]"+ ~"[\"]"? )
+    Name                    = ~r"[\w\d_%$€£¥&§#']+"
+    NameWithSpecialChars    = ~r"([\w\d_%$€£¥&§#'+\-*#<>\\.,;:–()]|(\\\"))+" 
     Separator               = strict_whitespace / bracket_open
     bracket_open            = '('
+    bracket_closed          = ')'
     ArgumentSeparator       = _ ',' _
     RangeSeparator          = _ ':' _
-    _                       = (~"[\t\v\f\r\n \u00A0\uFEFF]"*)
-    strict_whitespace       = ~"[\t\v\f\r\n \u00A0\uFEFF]"+
+    whitespace              = ~"[\t\v\f\r\n \u00A0\u2028\uFEFF]"
+    _                       = whitespace*
+    strict_whitespace       = whitespace+
     nothing                 = ''
 
     """
