@@ -18,3 +18,6 @@ from .complexFunctions import FindComplexFunctions
 from .makeAbsolute import makeExpressionAbsolute
 from .resolveSelf import resolveSelf
 from .resolveAsterisk import resolveAsterisk
+from .fixLabels import fixLabels
+from .filterGhosts import filterGhosts
+from .replaceDimensionNames import replaceDimensionNames
\ No newline at end of file
