@@ -23,9 +23,19 @@ class Flow(Element):
     def equation(self):
        return super().equation
 
+    def add_arr_equation(self, name, value):
+        s = self.model.flow(self.name + "[" + name + "]")
+        s.equation = value
+    def add_arr_empty(self, name):
+        return self.model.flow(self.name + "[" + name + "]")
+
+    def get_arr_equation(self, name):
+        return self.model.flows[self.name + "[" + name + "]"]
+
     @equation.setter
     def equation(self, equation):
-        self._equation = equation
+        if not self._handle_arrayed(equation):
+            self._equation = equation
         self.model.reset_cache()
         self.build_function_string()
         self.generate_function()
